// These defines are used in both the PRU assembly language and in the C
// code so they can only be simple defines.

// The commands to the PRU
#define CMD_NONE        0
#define CMD_EXIT        1
#define CMD_READ_TRACK  2
#define CMD_RPM         3
#define CMD_SEEK_FAST   4
#define CMD_SEEK_SLOW   5
#define CMD_SEEK_SLOW_TRACK0 6
#define CMD_CHECK_READY 7

// The command status. All commands other than CMD_READ_TRACK
// return their status when done. CMD_READ_TRACK returns
// CMD_STATUS_READ_STARTED when the read has started and CMD_STATUS_OK
// or an error status when the read is finished.
#define CMD_STATUS_WAIT_READY 0x100
#define CMD_STATUS_OK       0x200
#define CMD_STATUS_READY_ERR 0x300
#define CMD_STATUS_INDEX_TIMEOUT 0x400
#define CMD_STATUS_SEEK_COMPLETE_ERR 0x500
#define CMD_STATUS_READ_OVERFLOW 0x600
#define CMD_STATUS_READ_OVERRUN 0x700
#define CMD_STATUS_READ_STARTED 0x800
#define CMD_STATUS_DELTA_OVERFLOW 0x900

// These are the control parameters to communicate with the PRU code
// The INDD is because the C code uses these as indexes to uint32_t arrays
// and the assembly needs them as byte addresses. INDD is 4 for C and 1 for
// assembly.
#define PRU0_DDR_ADDR (0/INDD)      // Physical address of shared DDR memory
#define PRU0_DDR_SIZE (4/INDD)      // Size of shared DDR memory
#define PRU0_WRITE_PTR (8/INDD)	    // Delta write pointer
#define PRU0_CMD  (12/INDD)         // Command location
#define PRU0_CMD_DATA (16/INDD)     // Data for command
#define PRU0_DRIVE_STATUS (20/INDD) // Drive status, only valid when idle

#define GPIO0_TRACK_0    30
// Where the physical lines show up in the PRU registers
#define R30_SEEK_DIR_BIT  6
#define R30_STEP_BIT      7
#define R30_READ_ENABLE  15

#define R31_DRIVE_SEL         1
#define R31_SEEK_COMPLETE_BIT 2
#define R31_WRITE_FAULT_BIT   3
#define R31_READY_BIT         4
#define R31_INDEX_BIT         5

// Address in PRU code for stopping current operation
#define RESTART_ADDR 0x400
// Offset from start of PRU0_DATARAM to the PRU control register
#define PRU_CONTROL_REG  (0x22000/INDD)
#define PRU_STATUS_REG  (0x22004/INDD)
